==> xlr-status-event-module-22.3.0-804.946.jar: web/include/external-deployments/ducks/external-deployments.reducer.spec.ts <==
import { EventChannel } from 'redux-saga';
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore
import { EventSource } from 'mocksse';
import { folderExternalDeployments, initialState } from './external-deployments.reducer';
import {
    CreateStatusEvent,
    DeleteStatusEvent,
    EndpointExternalDeploymentEvent,
    ExternalDeployment,
    ExternalDeploymentPage,
    UpdateStatusEvent,
} from '../external-deployment.types';
import { SSE_REGISTRATION_URL } from '../constants';
import { subscribeToSse } from '../helper/utils';
import {
    baseExternalDeploymentEventMock,
    connectionServersMock,
    deploymentStateMock,
    deployServerMock,
    externalDeploymentMock,
    mockArgoWebhookSource,
    mockConfigDetails,
    mockDeployWebhookEventSource,
    mockSaveWebhookSourceFiltersRequest,
    mockServers,
    mockSetupLiveUpdateRequest,
    mockWebhookSourceFilters,
    mockWebhookSources,
} from '../__mocks__/external-deployments.mocks';

describe('external deployments reducer', () => {
    const {
        createApplicationStatus,
        deleteApplicationStatus,
        loadExternalDeployments,
        setConnectionServers,
        setIsLoading,
        setMaxAge,
        setSseStreamChannel,
        setExternalDeployments,
        setExternalDeploymentsCount,
        subscribeToSseStream,
        updateApplicationStatus,
        unsubscribeFromSseStream,
        deleteWebhookSource,
        removeWebhookSource,
        updateWebhookSourceFilters,
        loadFilterEventSource,
        setFilterEventSource,
        saveEventSource,
        createServer,
        loadServers,
        loadWebhookSources,
        loadWebhookSourceFilters,
        setConfigDetails,
        setServers,
        setLiveUpdate,
        setWebhookSources,
        setWebhookSourceFilters,
        addServerToServers,
        setCondition,
    } = folderExternalDeployments.actions;

    it('should have the initial state', () => {
        expect(folderExternalDeployments.name).toBe('folderExternalDeployments');
        expect(folderExternalDeployments.reducer(undefined, { type: 'default' })).toBe(initialState);
    });

    describe('reducers', () => {
        describe('createApplicationStatus', () => {
            it('should not update state', () => {
                const payload: EndpointExternalDeploymentEvent<CreateStatusEvent> = {
                    endpointId: '12',
                    state: {
                        ...baseExternalDeploymentEventMock,
                        statusGroup: 'success',
                        versionTag: { label: '1.0' },
                    },
                };
                const state = folderExternalDeployments.reducer(initialState, createApplicationStatus(payload));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('createServer', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, createServer(deployServerMock));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('deleteApplicationStatus', () => {
            it('should not update state', () => {
                const payload: EndpointExternalDeploymentEvent<DeleteStatusEvent> = {
                    endpointId: '12',
                    state: {
                        ...baseExternalDeploymentEventMock,
                        versionTag: { label: '1.0' },
                    },
                };
                const state = folderExternalDeployments.reducer(initialState, deleteApplicationStatus(payload));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('loadExternalDeployments', () => {
            it('should update state', () => {
                const payload: ExternalDeploymentPage = {
                    folderId: 'folderId',
                    page: 1,
                    resultsPerPage: 25,
                    orderBy: 'environment',
                    order: 'desc',
                };
                const state = folderExternalDeployments.reducer(initialState, loadExternalDeployments(payload));
                expect(state.page).toStrictEqual(payload);
            });
        });

        describe('loadServers', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadServers('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('loadWebhookSources', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadWebhookSources('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('loadWebhookSourceFilters', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadWebhookSourceFilters('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('setConnectionServers', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setConnectionServers(connectionServersMock));
                expect(state.connectionServers).toStrictEqual(connectionServersMock);
            });
        });

        describe('setConfigDetails', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setConfigDetails(mockConfigDetails));
                expect(state).toStrictEqual({ ...initialState, configDetails: mockConfigDetails });
            });
        });

        describe('setExternalDeployments', () => {
            it('should update state', () => {
                const payload: Array<ExternalDeployment> = [externalDeploymentMock];
                const state = folderExternalDeployments.reducer(initialState, setExternalDeployments(payload));
                expect(state.externalDeployments).toStrictEqual(payload);
            });
        });

        describe('setExternalDeploymentsCount', () => {
            it('should update state', () => {
                const payload = 100;
                const state = folderExternalDeployments.reducer(initialState, setExternalDeploymentsCount(payload));
                expect(state.count).toStrictEqual(payload);
            });
        });

        describe('setIsLoading', () => {
            it('should update state', () => {
                const payload = true;
                const state = folderExternalDeployments.reducer(initialState, setIsLoading(payload));
                expect(state.isLoading).toStrictEqual(payload);
            });
        });

        describe('setMaxAge', () => {
            it('should update state', () => {
                const payload = 20;
                const state = folderExternalDeployments.reducer(initialState, setMaxAge(payload));
                expect(state.maxAge).toStrictEqual(payload);
            });
        });

        describe('setServers', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setServers(mockServers));
                expect(state).toStrictEqual({ ...initialState, servers: mockServers });
            });
        });

        describe('setLiveUpdate', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, setLiveUpdate(mockSetupLiveUpdateRequest));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('setWebhookSources', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setWebhookSources(mockWebhookSources));
                expect(state).toStrictEqual({ ...initialState, webhookSources: mockWebhookSources });
            });
        });

        describe('setWebhookSourceFilters', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setWebhookSourceFilters(mockWebhookSourceFilters));
                expect(state).toStrictEqual({ ...initialState, webhookSourceFilters: mockWebhookSourceFilters });
            });
        });

        describe('addServerToServers', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, addServerToServers(deployServerMock));
                expect(state).toStrictEqual({ ...initialState, servers: [deployServerMock] });
            });
        });

        describe('setSseStreamChannel', () => {
            it('should update state', () => {
                const mockEventSource = new EventSource(SSE_REGISTRATION_URL);
                const payload: EventChannel<Event> = subscribeToSse(mockEventSource);
                const state = folderExternalDeployments.reducer(initialState, setSseStreamChannel(payload));
                expect(state.externalDeploymentChannel).toStrictEqual(payload);
            });
        });

        describe('subscribeToSseStream', () => {
            it('should not update state', () => {
                const state = folderExternalDeployments.reducer(initialState, subscribeToSseStream());
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('updateApplicationStatus', () => {
            it('should not update state', () => {
                const payload: EndpointExternalDeploymentEvent<UpdateStatusEvent> = {
                    endpointId: '12',
                    state: {
                        ...baseExternalDeploymentEventMock,
                        state: deploymentStateMock,
                        statusGroup: 'success',
                    },
                };
                const state = folderExternalDeployments.reducer(initialState, updateApplicationStatus(payload));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('updateWebhookSourceFilters', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, updateWebhookSourceFilters(mockSaveWebhookSourceFiltersRequest));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('unsubscribeFromSseStream', () => {
            it('should not update state', () => {
                const state = folderExternalDeployments.reducer(initialState, unsubscribeFromSseStream());
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('deleteWebhookSource', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, deleteWebhookSource('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('removeWebhookSource', () => {
            it('should update state', () => {
                const mockDeployWebhookSourceId = 'Configuration/Custom/Configuration1682004056084295907f2e9c654f049b';
                const state = folderExternalDeployments.reducer(
                    {
                        ...initialState,
                        webhookSources: mockWebhookSources,
                    },
                    removeWebhookSource(mockDeployWebhookSourceId),
                );
                expect(state).toStrictEqual({ ...initialState, webhookSources: [mockArgoWebhookSource] });
            });
        });

        describe('loadFilterEventSource', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadFilterEventSource('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('setFilterEventSource', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setFilterEventSource(mockDeployWebhookEventSource));
                expect(state).toStrictEqual({ ...initialState, filterEventSource: mockDeployWebhookEventSource });
            });
        });

        describe('saveEventSource', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, saveEventSource(mockDeployWebhookEventSource));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('setCondition', () => {
            it('should update state', () => {
                const payload = 'condition';
                const state = folderExternalDeployments.reducer(initialState, setCondition(payload));
                expect(state.condition).toStrictEqual(payload);
            });
        });
    });
});

==> xlr-status-event-module-22.3.8.jar: web/include/external-deployments/ducks/external-deployments.reducer.spec.ts <==
import { EventChannel } from 'redux-saga';
// eslint-disable-next-line @typescript-eslint/ban-ts-comment
// @ts-ignore
import { EventSource } from 'mocksse';
import { folderExternalDeployments, initialState } from './external-deployments.reducer';
import {
    CreateStatusEvent,
    DeleteStatusEvent,
    EndpointExternalDeploymentEvent,
    ExternalDeployment,
    ExternalDeploymentPage,
    UpdateStatusEvent,
} from '../external-deployment.types';
import { SSE_REGISTRATION_URL } from '../constants';
import { subscribeToSse } from '../helper/utils';
import {
    argoServerMock,
    baseExternalDeploymentEventMock,
    connectionServersMock,
    deploymentStateMock,
    deployServerMock,
    externalDeploymentMock,
    mockArgoWebhookSource,
    mockConfigDetails,
    mockDeployWebhookEventSource,
    mockSaveWebhookSourceFiltersRequest,
    mockServers,
    mockSetupLiveUpdateRequest,
    mockWebhookSourceFilters,
    mockWebhookSources,
} from '../__mocks__/external-deployments.mocks';
import { getApplicationStatusChannelSelector } from './external-deployments.selectors';

describe('external deployments reducer', () => {
    const {
        addServerToServers,
        createApplicationStatus,
        createServer,
        deleteApplicationStatus,
        deleteWebhookSource,
        getFilters,
        loadExternalDeployments,
        loadFilterEventSource,
        loadServers,
        loadWebhookSourceFilters,
        loadWebhookSources,
        patchExternalDeployments,
        refreshExternalDeployments,
        removeWebhookSource,
        saveEventSource,
        setCondition,
        setConfigDetails,
        setConnectionErrors,
        setConnectionServers,
        setDisconnectedServers,
        setExternalDeployments,
        setExternalDeploymentsCount,
        setFilterEventSource,
        setIsLoading,
        setLiveUpdate,
        setMaxAge,
        setPage,
        setPreSelectedServer,
        setServers,
        setSseStreamChannel,
        setWebhookSourceFilters,
        setWebhookSources,
        storeFilters,
        subscribeToSseStream,
        unsubscribeFromSseStream,
        updateApplicationStatus,
        updateBreadcrumbs,
        updateWebhookSourceFilters,
    } = folderExternalDeployments.actions;

    it('should have the initial state', () => {
        expect(folderExternalDeployments.name).toBe('folderExternalDeployments');
        expect(folderExternalDeployments.reducer(undefined, { type: 'default' })).toBe(initialState);
    });

    describe('reducers', () => {
        describe('createApplicationStatus', () => {
            it('should not update state', () => {
                const payload: EndpointExternalDeploymentEvent<CreateStatusEvent> = {
                    endpointId: '12',
                    state: {
                        ...baseExternalDeploymentEventMock,
                        statusGroup: 'success',
                        versionTag: { label: '1.0' },
                    },
                };
                const state = folderExternalDeployments.reducer(initialState, createApplicationStatus(payload));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('createServer', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, createServer(deployServerMock));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('deleteApplicationStatus', () => {
            it('should not update state', () => {
                const payload: EndpointExternalDeploymentEvent<DeleteStatusEvent> = {
                    endpointId: '12',
                    state: {
                        ...baseExternalDeploymentEventMock,
                        versionTag: { label: '1.0' },
                    },
                };
                const state = folderExternalDeployments.reducer(initialState, deleteApplicationStatus(payload));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('loadExternalDeployments', () => {
            it('should not update state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadExternalDeployments());
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('refreshExternalDeployments', () => {
            it('should not update state', () => {
                const state = folderExternalDeployments.reducer(initialState, refreshExternalDeployments());
                expect(state).toStrictEqual(state);
            });
        });

        describe('loadServers', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadServers('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('loadWebhookSources', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadWebhookSources('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('loadWebhookSourceFilters', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadWebhookSourceFilters('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('setConnectionServers', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setConnectionServers(connectionServersMock));
                expect(state.connectionServers).toStrictEqual(connectionServersMock);
            });
        });

        describe('setDisconnectedServers', () => {
            it('should update state', () => {
                const servers = ['srv1'];
                const state = folderExternalDeployments.reducer(initialState, setDisconnectedServers(servers));
                expect(state.disconnectedServers).toStrictEqual(servers);
            });
        });

        describe('setConnectionErrors', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setConnectionErrors(['someConnectionError']));
                expect(state.connectionErrors).toStrictEqual(['someConnectionError']);
            });
        });

        describe('setConfigDetails', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setConfigDetails(mockConfigDetails));
                expect(state).toStrictEqual({ ...initialState, configDetails: mockConfigDetails });
            });
        });

        describe('setExternalDeployments', () => {
            it('should update state', () => {
                const payload: Array<ExternalDeployment> = [externalDeploymentMock];
                const state = folderExternalDeployments.reducer(initialState, setExternalDeployments(payload));
                expect(state.externalDeployments).toStrictEqual(payload);
            });
        });

        describe('setExternalDeploymentsCount', () => {
            it('should update state', () => {
                const payload = 100;
                const state = folderExternalDeployments.reducer(initialState, setExternalDeploymentsCount(payload));
                expect(state.count).toStrictEqual(payload);
            });
        });

        describe('setIsLoading', () => {
            it('should update state', () => {
                const payload = true;
                const state = folderExternalDeployments.reducer(initialState, setIsLoading(payload));
                expect(state.isLoading).toStrictEqual(payload);
            });
        });

        describe('setMaxAge', () => {
            it('should update state', () => {
                const payload = 20;
                const state = folderExternalDeployments.reducer(initialState, setMaxAge(payload));
                expect(state.maxAge).toStrictEqual(payload);
            });
        });

        describe('setPreSelectedServer', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setPreSelectedServer(argoServerMock));
                expect(state).toStrictEqual({ ...initialState, preSelectedServer: argoServerMock });
            });
        });

        describe('setServers', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setServers(mockServers));
                expect(state).toStrictEqual({ ...initialState, servers: mockServers });
            });
        });

        describe('setLiveUpdate', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, setLiveUpdate(mockSetupLiveUpdateRequest));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('setWebhookSources', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setWebhookSources(mockWebhookSources));
                expect(state).toStrictEqual({ ...initialState, webhookSources: mockWebhookSources });
            });
        });

        describe('setWebhookSourceFilters', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setWebhookSourceFilters(mockWebhookSourceFilters));
                expect(state).toStrictEqual({ ...initialState, webhookSourceFilters: mockWebhookSourceFilters });
            });
        });

        describe('addServerToServers', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, addServerToServers(deployServerMock));
                expect(state).toStrictEqual({ ...initialState, servers: [deployServerMock] });
            });
        });

        describe('setSseStreamChannel', () => {
            it('should update state', () => {
                const mockEventSource = new EventSource(SSE_REGISTRATION_URL);
                const payload: EventChannel<Event> = subscribeToSse(mockEventSource);
                const state = folderExternalDeployments.reducer(initialState, setSseStreamChannel(payload));
                expect(state.externalDeploymentChannel).toStrictEqual(payload);
            });
        });

        describe('subscribeToSseStream', () => {
            it('should not update state', () => {
                const state = folderExternalDeployments.reducer(initialState, subscribeToSseStream());
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('updateApplicationStatus', () => {
            it('should not update state', () => {
                const payload: EndpointExternalDeploymentEvent<UpdateStatusEvent> = {
                    endpointId: '12',
                    state: {
                        ...baseExternalDeploymentEventMock,
                        state: deploymentStateMock,
                        statusGroup: 'success',
                    },
                };
                const state = folderExternalDeployments.reducer(initialState, updateApplicationStatus(payload));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('updateWebhookSourceFilters', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, updateWebhookSourceFilters(mockSaveWebhookSourceFiltersRequest));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('unsubscribeFromSseStream', () => {
            it('should not update state', () => {
                const state = folderExternalDeployments.reducer(initialState, unsubscribeFromSseStream());
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('deleteWebhookSource', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, deleteWebhookSource('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('removeWebhookSource', () => {
            it('should update state', () => {
                const mockDeployWebhookSourceId = 'Configuration/Custom/Configuration1682004056084295907f2e9c654f049b';
                const state = folderExternalDeployments.reducer(
                    {
                        ...initialState,
                        webhookSources: mockWebhookSources,
                    },
                    removeWebhookSource(mockDeployWebhookSourceId),
                );
                expect(state).toStrictEqual({ ...initialState, webhookSources: [mockArgoWebhookSource] });
            });
        });

        describe('loadFilterEventSource', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, loadFilterEventSource('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('setFilterEventSource', () => {
            it('should update state', () => {
                const state = folderExternalDeployments.reducer(initialState, setFilterEventSource(mockDeployWebhookEventSource));
                expect(state).toStrictEqual({ ...initialState, filterEventSource: mockDeployWebhookEventSource });
            });
        });

        describe('saveEventSource', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, saveEventSource(mockDeployWebhookEventSource));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('setCondition', () => {
            it('should update state', () => {
                const payload = 'condition';
                const state = folderExternalDeployments.reducer(initialState, setCondition(payload));
                expect(state.condition).toStrictEqual(payload);
            });
        });

        describe('setPage', () => {
            it('should update state', () => {
                const payload: ExternalDeploymentPage = {
                    folderId: 'folder-1',
                    order: 'asc',
                    orderBy: 'environment',
                    page: 1,
                    resultsPerPage: 10,
                };
                const state = folderExternalDeployments.reducer(initialState, setPage(payload));
                expect(state.page).toStrictEqual(payload);
            });
        });

        describe('storeFilters', () => {
            it('should not update state', () => {
                const state = folderExternalDeployments.reducer(initialState, storeFilters());
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('getFilters', () => {
            it('should update state', () => {
                const payload = 'folder-1';
                const state = folderExternalDeployments.reducer(initialState, getFilters(payload));
                expect(state.page.folderId).toStrictEqual(payload);
            });
        });

        describe('patchExternalDeployments', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, patchExternalDeployments('SomeConfigurationId'));
                expect(state).toStrictEqual(initialState);
            });
        });

        describe('updateBreadcrumbs', () => {
            it('should do nothing with state', () => {
                const state = folderExternalDeployments.reducer(initialState, updateBreadcrumbs({ id: 'folderId', title: 'Folder' }));
                expect(state).toStrictEqual(initialState);
            });
        });
    });

    it('should test getApplicationStatusChannelSelector', () => {
        expect(getApplicationStatusChannelSelector({ folderExternalDeployments: initialState })).toBe(undefined);
    });
});
